import { Cluster, ClusterCreateParams, ClusterDefaultConfig, V2ClusterUpdateParams, Credentials, ImportClusterParams, PlatformType, PreflightHardwareRequirements, PresignedUrl } from '../../../common/api/types';
import { AxiosResponse } from 'axios';
import { ClustersAPIGetPresignedOptions } from './types';
declare const ClustersAPI: {
    makeBaseURI(clusterId?: string | undefined): string;
    makeDownloadsBaseURI(clusterId: Cluster['id']): string;
    makeLogsBaseURI(clusterId: Cluster['id']): string;
    makeDownloadsCredentialsBaseURI(clusterId: Cluster['id']): string;
    makeDownloadsCredentialsPresignedBaseURI(clusterId: Cluster['id']): string;
    makeDownloadsFilesPresignedBaseURI(clusterId: Cluster['id']): string;
    makeSupportedPlatformsBaseURI(clusterId: Cluster['id']): string;
    makeActionsBaseURI(clusterId: string): string;
    downloadClusterCredentials(clusterId: Cluster['id'], fileName: string): Promise<AxiosResponse<Blob, any>>;
    getPresignedForClusterCredentials({ clusterId, fileName, hostId, logsType, }: ClustersAPIGetPresignedOptions): Promise<AxiosResponse<PresignedUrl, any>>;
    getPresignedForClusterFiles({ clusterId, fileName, hostId, logsType, }: ClustersAPIGetPresignedOptions): Promise<AxiosResponse<PresignedUrl, any>>;
    list(): Promise<AxiosResponse<Cluster[], any>>;
    get(clusterId: Cluster['id']): Promise<AxiosResponse<Cluster, any>>;
    getSupportedPlatforms(clusterId: Cluster['id']): Promise<AxiosResponse<PlatformType[], any>>;
    getPreflightRequirements(clusterId: Cluster['id']): Promise<AxiosResponse<PreflightHardwareRequirements, any>>;
    getDefaultConfig(): Promise<AxiosResponse<ClusterDefaultConfig, any>>;
    deregister(clusterId: Cluster['id']): Promise<AxiosResponse<void, any>>;
    register(params: ClusterCreateParams): Promise<AxiosResponse<Cluster, any>>;
    update(clusterId: Cluster['id'], params: V2ClusterUpdateParams): Promise<AxiosResponse<Cluster, any>>;
    install(clusterId: Cluster['id']): Promise<AxiosResponse<Cluster, any>>;
    cancel(clusterId: Cluster['id']): Promise<AxiosResponse<Cluster, any>>;
    reset(clusterId: Cluster['id']): Promise<AxiosResponse<Cluster, any>>;
    registerAddHosts(params: ImportClusterParams): Promise<AxiosResponse<Cluster, any>>;
    allowAddHosts(clusterId: Cluster['id']): Promise<AxiosResponse<Cluster, any>>;
    downloadLogs(clusterId: Cluster['id'], hostId?: string | undefined): Promise<AxiosResponse<Blob, any>>;
    getCredentials(clusterId: Cluster['id']): Promise<AxiosResponse<Credentials, any>>;
    listByOpenshiftId(openshiftId: Cluster['openshiftClusterId']): Promise<AxiosResponse<Cluster[], any>>;
    listBySubscriptionIds(subscriptionIds: Cluster['amsSubscriptionId'][]): Promise<AxiosResponse<Cluster[], any>>;
};
export default ClustersAPI;
